@@ -48,7 +48,7 @@ score_dialog (GtkWindow *parent)
 
   dialog = gtk_dialog_new_with_buttons (_("Score"),
                                         parent,
-                                        GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        GTK_DIALOG_DESTROY_WITH_PARENT /*| GTK_DIALOG_MODAL*/,
                                         GTK_STOCK_CLEAR, GTK_RESPONSE_REJECT,
                                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                         NULL);
