@@ -193,7 +193,7 @@ static void about_cb (GtkWidget *widget, gpointer data)
 		char *filename = NULL;
 
 		filename = gnome_program_locate_file (NULL,
-				GNOME_FILE_DOMAIN_PIXMAP, "gnome-nibbles.png",
+				GNOME_FILE_DOMAIN_APP_PIXMAP, "gnome-nibbles.png",
 				TRUE, NULL);
 		if (filename != NULL)
 		{
@@ -227,8 +227,8 @@ static gint expose_event_cb (GtkWidget *widget, GdkEventExpose *event)
 
 static gint key_press_cb (GtkWidget *widget, GdkEventKey *event)
 {
-	gnibbles_keypress_worms (event->keyval);
 	hide_cursor ();
+	return gnibbles_keypress_worms (event->keyval);
 }
 
 static void draw_board ()
@@ -550,6 +550,27 @@ static void set_bg_color ()
 	g_object_unref (G_OBJECT (tmp_image));
 }
 
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	char buf[10];
+	sprintf (buf, "%d.%d", properties->gamespeed, properties->fakes);
+
+	top = gnome_score_get_notable("gnibbles", buf, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (game_menu[3].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (game_menu[3].widget, FALSE);
+	}
+}
+
 gboolean
 show_cursor_cb (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
@@ -652,6 +673,8 @@ int main (int argc, char **argv)
 
 	setup_window ();
 
+	update_score_state ();
+
 	gnibbles_load_pixmap (window);
 
 	gtk_widget_show (window);
