@@ -18,13 +18,17 @@
  * 	    Juan Pablo Mendoza <pablo_juan@yahoo.com>
  */
 
+#undef G_DISABLE_DEPRECATED
+#undef GDK_DISABLE_DEPRECATED
+#undef GTK_DISABLE_DEPRECATED
+#undef GNOME_DISABLE_DEPRECATED
+
 #include <config.h>
 #include <math.h>
 #include "gnome-canvas-pimage.h"
 #include "libgnomecanvas/gnome-canvas-util.h"
 #include "libgnomeui/gnometypebuiltins.h"
 
-
 enum {
 	ARG_0,
 	ARG_IMAGE,
